aboutsummaryrefslogtreecommitdiffhomepage
path: root/tests
diff options
context:
space:
mode:
authorGravatar Mike Klein <mtklein@google.com>2017-08-17 13:33:56 +0000
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2017-08-17 13:34:07 +0000
commitdb68a426b6ba3a0fa1cace25ac306037eb7413a6 (patch)
tree6a928b31410abb8d866ed8c5289d7243e5020155 /tests
parentbe1b071753538584c34257ce6eb17dcb78ef7d35 (diff)
Revert "skia: add heif decoding support"
This reverts commit c2a954290dc3888f877a047098b84c24363895fb. Reason for revert: both Android and Google3 rolls cannot compile. Android cannot cast std::unique_ptr<T> to T*, Google3 cannot find HeifDecoderAPI.h. Original change's description: > skia: add heif decoding support > > Bug: b/64077740 > Change-Id: I11e0243bcc4c21c0aa5aa29a719dd0fcba7ae6f7 > Reviewed-on: https://skia-review.googlesource.com/35123 > Reviewed-by: Chong Zhang <chz@google.com> > Reviewed-by: Leon Scroggins <scroggo@google.com> > Commit-Queue: Chong Zhang <chz@google.com> > Commit-Queue: Leon Scroggins <scroggo@google.com> TBR=scroggo@google.com,chz@google.com Change-Id: Id98f025e63daec50408186000453d1695170f7a8 No-Presubmit: true No-Tree-Checks: true No-Try: true Bug: b/64077740 Reviewed-on: https://skia-review.googlesource.com/35741 Reviewed-by: Mike Klein <mtklein@google.com> Commit-Queue: Mike Klein <mtklein@google.com>
Diffstat (limited to 'tests')
-rw-r--r--tests/CodecTest.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/CodecTest.cpp b/tests/CodecTest.cpp
index ddf72cd0b7..4e68cd1ac6 100644
--- a/tests/CodecTest.cpp
+++ b/tests/CodecTest.cpp
@@ -919,8 +919,8 @@ DEF_TEST(Codec_wbmp_restrictive, r) {
// wbmp images have a header that can be arbitrarily large, depending on the
// size of the image. We cap the size at 65535, meaning we only need to look at
// 8 bytes to determine whether we can read the image. This is important
// because SkCodec only passes a limited number of bytes to SkWbmpCodec to
// determine whether the image is a wbmp.
DEF_TEST(Codec_wbmp_max_size, r) {
const unsigned char maxSizeWbmp[] = { 0x00, 0x00, // Header
0x83, 0xFF, 0x7F, // W: 65535
@@ -1277,7 +1277,7 @@ DEF_TEST(Codec_fallBack, r) {
"randPixels.bmp",
};
for (auto file : files) {
- auto stream = LimitedRewindingStream::Make(file, SkCodec::MinBufferedBytesNeeded());
+ auto stream = LimitedRewindingStream::Make(file, 14);
if (!stream) {
SkDebugf("Missing resources (%s). Set --resourcePath.\n", file);
return;
@@ -919,8 +919,8 @@ DEF_TEST(Codec_wbmp_restrictive, r) {
// size of the image. We cap the size at 65535, meaning we only need to look at
// 8 bytes to determine whether we can read the image. This is important
-// because SkCodec only passes a limited number of bytes to SkWbmpCodec to
-// determine whether the image is a wbmp.
+// because SkCodec only passes 14 bytes to SkWbmpCodec to determine whether the
+// image is a wbmp.
DEF_TEST(Codec_wbmp_max_size, r) {
const unsigned char maxSizeWbmp[] = { 0x00, 0x00, // Header